import { useEffect, useRef } from 'react';

export type DialogProps = {
  onClose: () => void;
  open: boolean;
  children?: React.ReactNode;
  className?: string;
};

export const Dialog = (props: DialogProps) => {
  const ref = useRef<HTMLDialogElement>(null);

  useEffect(() => {
    if (props.open) ref.current?.showModal();
    else ref.current?.close();
  }, [props.open]);

  return (
    <dialog className={'fixed inset-0 z-10 overflow-y-auto rounded p-4 bg-light border'} ref={ref} onClose={() => props.onClose()}>
      <form method="dialog" className={'flex flex-col gap-4 ' + (props?.className ? props?.className : '')}>
        {props.children}
      </form>
    </dialog>
  );
};
