import React from 'react';
import { useGraphQueryResult, useQuerybuilderGraph } from '@graphpolaris/shared/lib/data-access';
import VisualizationBar from './bar';
import { VisualizationManagerType } from '../hooks';
import { Recommender, NoData, Querying } from '../views';

export const VisualizationPanel = ({ manager, fullSize }: { manager: VisualizationManagerType; fullSize: () => void }) => {
  const query = useQuerybuilderGraph();
  const graphQueryResult = useGraphQueryResult();

  const renderContent = () => {
    if (graphQueryResult.queryingBackend) {
      return <Querying />;
    } else if (graphQueryResult.nodes.length === 0) {
      return <NoData dataAvailable={query.nodes.length > 0} />;
    } else if (manager.tabs.length === 0) {
      return <Recommender onClick={(id: string) => manager.changeActive(id)} />;
    }
    return <div className="w-full h-full flex">{manager.renderComponent()}</div>;
  };

  return (
    <div className="vis-panel h-full w-full flex flex-col border bg-light">
      <VisualizationBar manager={manager} fullSize={fullSize} />
      <div className="grow overflow-y-auto" style={graphQueryResult.nodes.length === 0 ? { overflow: 'hidden' } : {}}>
        {renderContent()}
      </div>
    </div>
  );
};
